import 'dart:io';

import 'package:checked_yaml/checked_yaml.dart';
import 'package:android_notification_icons/constants.dart';
import 'package:android_notification_icons/validator.dart';
import 'package:json_annotation/json_annotation.dart';

part 'config.g.dart';

@JsonSerializable(
  anyMap: true,
  checked: true,
  disallowUnrecognizedKeys: true,
)
class Config {
  const Config({
    required this.imagePath,
    required this.iconName,
  });

  static Config fromYaml({required String filePath}) {
    // ファイルの存在可否
    final yamlFile = File(filePath);
    if (!yamlFile.existsSync()) {
      throw Exception('File not found: $filePath');
    }
    final yamlContent = yamlFile.readAsStringSync();
    return checkedYamlDecode<Config>(
      yamlContent,
      (Map? json) {
        // allowNullをfalseにすればjsonがnullの場合内部で例外が発生するが、クロージャーでは変わらずoptionalなのでこちらで処理しておく。
        if (json == null) {
          throw Exception('Yaml file is empty: $filePath');
        }
        if (json[Constants.packageName] == null) {
          throw Exception('${Constants.packageName} is not found: $filePath');
        }
        return Config.fromJson(json[Constants.packageName]);
      },
      allowNull: true,
    );
  }

  @JsonKey(name: 'image_path')
  final String imagePath;

  @JsonKey(name: 'icon_name', defaultValue: 'ic_notification')
  final String iconName;

  // もしも他のプラットフォームに対応させるのであれば、こちらにプラットフォームが区別できる引数を与えて処理を追加する。
  bool get validateIconName => Validator.validateAndroidIconName(iconName);

  factory Config.fromJson(Map json) => _$ConfigFromJson(json);

  Map<String, dynamic> toJson() => _$ConfigToJson(this);
}

const hoge = r'''

''';
