import 'package:android_notification_icons/config.dart';
import 'package:path/path.dart' as path;
import 'package:test/test.dart';
import 'package:test_descriptor/test_descriptor.dart' as d;

import 'yaml_template.dart' as template;

void main() {
  group('#fromYaml', () {
    late String testDirPath;
    setUpAll(() async {
      testDirPath = path.join(d.sandbox, 'test_dir');
      await d.dir('test_dir', [
        d.file('default_pubspec.yaml', template.pubspecTemplate),
        d.file('option_pubspec.yaml', template.addOptionPubspecTemplate),
        d.file('empty_pubspec.yaml', template.emptyPubspecTemplate),
        d.file('not_define_pubspec.yaml', template.notDefinePubspecTemplate),
      ]).create();
    });
    group('問題ない場合、Configクラスを返却する', () {
      test('オプションなし 各プロパティにデフォルト値が設定される', () {
        final config = Config.fromYaml(
            filePath: path.join(testDirPath, 'default_pubspec.yaml'));
        expect(config.iconName, equals('ic_notification'));
        expect(config.imagePath, equals('assets/images/ic_launcher.png'));
      });
      test('オプションあり 設定された値が設定される', () {
        final config = Config.fromYaml(
            filePath: path.join(testDirPath, 'option_pubspec.yaml'));
        expect(config.iconName, equals('custom_ic_notification'));
        expect(config.imagePath, equals('assets/images/ic_launcher.png'));
      });
    });
    group('エラーをthrowする', () {
      test('ファイルが見つからなかった場合、エラーを throw する', () {
        expect(
          () => Config.fromYaml(filePath: path.join(testDirPath, 'not_found.yaml')),
          throwsA(isA<Exception>()),
        );
      });
      test('ファイルが空だった場合、エラーを throw する', () {
        expect(
          () => Config.fromYaml(filePath: path.join(testDirPath, 'empty_pubspec.yaml')),
          throwsA(isA<Exception>()),
        );
      });
      test('ファイル内に`android_notification_icons`定義が見つからなかった場合、エラーを throw する', () {
        expect(
          () => Config.fromYaml(filePath: path.join(testDirPath, 'not_define_pubspec.yaml')),
          throwsA(isA<Exception>()),
        );
      });
    });
  });
}
